#
# spec file for package fcitx5-gtk
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           fcitx5-gtk
Version:        5.1.3
Release:        1.2
Summary:        Gtk im module for fcitx5 and glib based dbus client library
License:        LGPL-2.1-or-later
Group:          System/I18n/Chinese
URL:            https://github.com/fcitx/fcitx5-gtk
Source:         https://download.fcitx-im.org/fcitx5/%{name}/%{name}-%{version}.tar.zst
BuildRequires:  cmake
BuildRequires:  extra-cmake-modules
BuildRequires:  fcitx5-devel
BuildRequires:  fmt-devel
BuildRequires:  gcc-c++
BuildRequires:  glib2-devel
BuildRequires:  gobject-introspection-devel
BuildRequires:  gtk2-devel
BuildRequires:  gtk3-devel
BuildRequires:  libxkbcommon-devel
BuildRequires:  zstd
%if 0%{?suse_version} >= 1550
BuildRequires:  gtk4-devel
%endif

%description
Gtk im module for fcitx5 and glib based dbus client library.

%package -n libFcitx5GClient-devel
Summary:        Development files for libFcitx5GClient
Group:          Development/Libraries/C and C++
Requires:       libFcitx5GClient2 = %{version}

%description -n libFcitx5GClient-devel
This package provides development files for libFcitx5GClient.

%package -n libFcitx5GClient2
Summary:        GClient library for fcitx5
Group:          System/Libraries

%description -n libFcitx5GClient2
This package provides GClient library for fcitx5.

%package -n fcitx5-gtk2
Summary:        GTK+ 2.0 im module for fcitx5
Group:          System/I18n/Chinese
Supplements:    (fcitx5 and libgtk-2_0-0)
Provides:       fcitx-gtk2 = %{version}
Obsoletes:      fcitx-gtk2 <= 4.2.9.8
%{gtk2_immodule_requires}

%description -n fcitx5-gtk2
This package provides GTK+ 2.0 im module for fcitx5.

%package -n fcitx5-gtk3
Summary:        GTK+ 3.0 im module for fcitx5
Group:          System/I18n/Chinese
Supplements:    (fcitx5 and libgtk-3-0)
Provides:       fcitx-gtk3 = %{version}
Obsoletes:      fcitx-gtk3 <= 4.2.9.8
%{gtk3_immodule_requires}

%description -n fcitx5-gtk3
This package provides GTK+ 3.0 im module for fcitx5.

%if 0%{?suse_version} >= 1550
%package -n fcitx5-gtk4
Summary:        GTK+ 4.0 im module for fcitx5
Group:          System/I18n/Chinese
Requires(post): glib2-tools
Requires(postun): glib2-tools
Supplements:    (fcitx5 and libgtk-4-1)

%description -n fcitx5-gtk4
This package provides GTK+ 4.0 im module for fcitx5.
%endif

%package -n typelib-1_0-FcitxG-1_0
Summary:        Introspection bindings for fcitx5
Group:          System/Libraries
Provides:       typelib-1_0-Fcitx-1_0 = %{version}
Obsoletes:      typelib-1_0-Fcitx-1_0 <= 4.2.9.8

%description -n typelib-1_0-FcitxG-1_0
This package provides the GObject Introspection bindings for fcitx5.

%prep
%setup -q

%build
%if 0%{?suse_version} < 1550
%cmake -DENABLE_GTK4_IM_MODULE=OFF
%else
%cmake
%endif
%make_build

%install
%cmake_install

%post -n libFcitx5GClient2 -p /sbin/ldconfig

%post -n fcitx5-gtk2
%{gtk2_immodule_post}

%post -n fcitx5-gtk3
%{gtk3_immodule_post}

%postun -n libFcitx5GClient2 -p /sbin/ldconfig

%postun -n fcitx5-gtk2
%{gtk2_immodule_postun}

%postun -n fcitx5-gtk3
%{gtk3_immodule_postun}

%if 0%{?suse_version} >= 1550
%post -n fcitx5-gtk4
if [ -d %{_libdir}/gtk-4.0/4.0.0/immodules ]; then
if [ -x %{_bindir}/gio-querymodules-64 ]; then
  %{_bindir}/gio-querymodules-64 %{_libdir}/gtk-4.0/4.0.0/immodules
else
  %{_bindir}/gio-querymodules %{_libdir}/gtk-4.0/4.0.0/immodules
fi
fi

%postun -n fcitx5-gtk4
if [ $1 -eq 0 ]; then
if [ -d %{_libdir}/gtk-4.0/4.0.0/immodules ]; then
if [ -x %{_bindir}/gio-querymodules-64 ]; then
  %{_bindir}/gio-querymodules-64 %{_libdir}/gtk-4.0/4.0.0/immodules
else
  %{_bindir}/gio-querymodules %{_libdir}/gtk-4.0/4.0.0/immodules
fi
fi
fi
%endif

%files -n libFcitx5GClient-devel
%doc README.md
%license LICENSES
%dir %{_includedir}/Fcitx5
%dir %{_includedir}/Fcitx5/GClient
%dir %{_includedir}/Fcitx5/GClient/fcitx-gclient
%{_includedir}/Fcitx5/GClient/fcitx-gclient/fcitxgclient.h
%{_includedir}/Fcitx5/GClient/fcitx-gclient/fcitxgwatcher.h
%{_libdir}/cmake/Fcitx5GClient
%{_libdir}/libFcitx5GClient.so
%{_libdir}/pkgconfig/Fcitx5GClient.pc
%{_datadir}/gir-1.0/FcitxG-1.0.gir

%files -n typelib-1_0-FcitxG-1_0
%{_libdir}/girepository-1.0/FcitxG-1.0.typelib

%files -n libFcitx5GClient2
%{_libdir}/libFcitx5GClient.so.2
%{_libdir}/libFcitx5GClient.so.%{version}

%files -n fcitx5-gtk2
%{_bindir}/fcitx5-gtk2-immodule-probing
%{_libdir}/gtk-2.0/2.10.0/immodules/im-fcitx5.so

%files -n fcitx5-gtk3
%{_bindir}/fcitx5-gtk3-immodule-probing
%{_libdir}/gtk-3.0/3.0.0/immodules/im-fcitx5.so

%if 0%{?suse_version} >= 1550
%files -n fcitx5-gtk4
%{_bindir}/fcitx5-gtk4-immodule-probing
%dir %{_libdir}/gtk-4.0/4.0.0/immodules
%{_libdir}/gtk-4.0/4.0.0/immodules/libim-fcitx5.so
%endif

%changelog
* Thu May 23 2024 Marguerite Su <i@marguerite.su>
- update to 5.1.3
  * Add <algorithm> for std::max
  * Also use SLIDE_Y for xdg_popup window
* Mon Feb  5 2024 Marguerite Su <i@marguerite.su>
- update to 5.1.1
  * add delete surrounding to process batch
* Sun Aug 20 2023 Marguerite Su <i@marguerite.su>
- update to 5.1.0
  * add im module probing program
  * skip gtk im module probing for only plugin option
  * implement new PageButtonAlignment for gtk client side ui
  * gdk_layout is not happy with width or height 0 rect anymore
* Mon May 22 2023 Marguerite Su <i@marguerite.su>
- Update to 5.0.23
  * hotfix to fix a potential crash under wayland
* Fri Mar 17 2023 Dirk Müller <dmueller@suse.com>
- update to 5.0.22:
  * Implement notify-focus-out signal
  * Change GtkIMContext.reset to always commit preedit
  * preedit when focus out need to happen before has_focus set
* Thu Nov 24 2022 Fusion Future <qydwhotmail@gmail.com>
- Update to 5.0.21
  * Workaround a mutter bug that client side input panel may freeze
    nautilus if typing in rename dialog.
  * Workaround a gtk4 bug that breaks the cursor position calculation
    when typing in the gtk popover window.
* Sun Nov 20 2022 Tranter Madi <trmdi@yandex.com>
- update version 5.0.20
  * remove backport-c772576.diff
* Sun Nov 13 2022 Tranter Madi <trmdi@yandex.com>
- backport bugfix from upstream
  * fix a bug when press Enter in Firefox.
    See https://github.com/fcitx/fcitx5-gtk/issues/22
  * add backport-c772576.diff
* Sat Oct  1 2022 Marguerite Su <i@marguerite.su>
- update version 5.0.19
  * workaround GTK4 bug 5200 that affects input method engines that
    commit strings and keep the state at the same time. specifically
    hangul / table(wubi etc) in chinese-addons and some m17n engines
* Wed Sep 21 2022 Marguerite Su <i@marguerite.su>
- update version 5.0.18
  * Fix the order of add_subdirectory, subdirectory need to be added
    after set required variables
  * Hide non public function
- change in 5.0.17
  * Add an option for build only im module
* Mon Jul  4 2022 Haochuan Chen <yjcoshc@mail.nankai.edu.cn>
- Update to version 5.0.16
  * Also monitor user theme config file.
  * Make sure we set client_window/widget to null if app set it.
- Update to version 5.0.15
  * gio unix is only im modules's dependency.
  * Do now show size 0 window.
  * Depend on gio-unix-2.0 (#18)
- Update to version 5.0.14
  * properly use g_cancellable in watcher.
  * Free the address returned from g_dbus_address_get_for_bus_sync
  * Change the dbus connection used by watcher
  * Set no exit on close for the dbus connection used by fcitx im module.
  * Add shadow margin support to gtk client side input panel
  * fix: Compatible with glib 2.5.58 < 2.60 (#17)
* Sat Mar 12 2022 Marguerite Su <i@marguerite.su>
- update version 5.0.13
  * Revert to use the shared font map
  * Keep gtkinputwindow screen to be same as the client_window
    otherwise for application that opens multiple Gdk display,
    it may cause issue
  * check if prgname is not null
  * Implement ProcessKeyEventBatch in gclient
* Sat Feb 12 2022 Marguerite Su <i@marguerite.su>
- update version 5.0.12
  * Fix language tag in client side ui
  * Enable build without X11 if gtk doesn't build with X11
  * Fix paging button not clickable under vertical layout
* Tue Feb  8 2022 Marguerite Su <i@marguerite.su>
- drop baselibs.conf, no consumer yet
* Sat Jan 29 2022 Marguerite Su <i@marguerite.su>
- fix baselibs.conf
* Tue Jan 25 2022 Marguerite Su <i@marguerite.su>
- update version 5.0.11
  * Allow positioning input windows more freely
* Sat Jan 15 2022 Marguerite Su <i@marguerite.su>
- fix requirements
* Wed Dec 15 2021 Marguerite Su <i@marguerite.su>
- update version 5.0.10
  * Try to workaround wayland window blinking as much as possible
* Sat Nov  6 2021 J <hj@powersnail.com>
- update to version 5.0.9
  * Pickup font DPI change from Gtk at runtime
  * Prefer sync mode under Gtk4
  * Fix Gtk4 preedit color.
* Wed Oct 27 2021 J <hj@powersnail.com>
- update version 5.0.8
* Wed May  5 2021 Marguerite Su <i@marguerite.su>
- update version 5.0.7
  * Fix client side ui positioning for gtk3
- changes in version 5.0.6
  * Fix key handling for re-forwarding and a memory leak
- changes in version 5.0.5
  * Implement fixed line height in client side ui
  * add support for client side input window on wayland
    to get the correct positioning. Due to some limitation
    on wayland, you may want to disable the popup fading
    effect under kwin.
* Tue Mar 16 2021 Marguerite Su <i@marguerite.su>
- update version 5.0.4
  * add support for client side input window on wayland
    to get the correct positioning. Due to some limitation
    on wayland, you may want to disable the popup fading
    effect under kwin
* Sat Jan 30 2021 Marguerite Su <i@marguerite.su>
- update version 5.0.3
  * Add support for Gtk4
* Sun Dec  6 2020 Marguerite Su <i@marguerite.su>
- update version 5.0.1
* Sun Nov  8 2020 Marguerite Su <i@marguerite.su>
- update version 5.0.0
* Thu Sep  3 2020 Marguerite Su <i@marguerite.su>
- update version 4.99.0+git20200820.d26dd52
* Tue Mar  3 2020 Xu Zhao <i@xuzhao.net>
- update version 4.99.0+git20191111.6f9ef64
  * Replace clang-format.sh with git hook
  * Clean up the code
  * Update dbus path for gtk im
* Wed Aug 21 2019 Marguerite Su <i@marguerite.su>
- update version 4.99.0+git20180920.b17b2de
  * Use base as counter part for text color
  * Check the drawable is a X11 thing before using it
* Sun Aug 26 2018 i@marguerite.su
- initial package
